function TEB = eulmat(phi, theta, psi)

# usage: TEB = eulmat(phi, theta, psi)

# This function computes the transformation matrix from
# body fixed coordinates to earth fixed coordinates from
# the Euler angles:
#
#                  [x]_E = [T]_EB * [x]_B
#
# The same matrix represents the rotation tensor.
#
# Input   phi, theta, psi     Euler angles in radians
#
# where   phi    describes the rotation about the body x-axis
#         theta  describes the rotation about the body y-axis
#         psi    describes the rotation about the body z-axis
#
# --------------------------------------------------------------


# Trigonometric Functions

  sphi = sin(phi);
  cphi = cos(phi);
  spsi = sin(psi);
  cpsi = cos(psi);
  sthe = sin(theta);
  cthe = cos(theta);

# Matrix elements

  TEB = [ cthe * cpsi, sphi * sthe * cpsi - cphi * spsi, cphi * sthe * cpsi + sphi * spsi;
          cthe * spsi, sphi * sthe * spsi + cphi * cpsi, cphi * sthe * spsi - sphi * cpsi;
          -sthe, sphi * cthe, cphi * cthe ];
              
endfunction
